@@ -17,7 +17,8 @@
 #include <QIconEngine>
 #include <QPainter>
 
-#include <KStandardDirs>
+#include <QStandardPaths>
+#include <QDebug>
 
 
 using namespace Konversation;
@@ -34,6 +35,7 @@ class LedIconEngine : public QIconEngine
         // QIconEngine
         virtual void paint(QPainter *painter, const QRect &rect, QIcon::Mode mode, QIcon::State state);
         virtual QPixmap pixmap(const QSize &size, QIcon::Mode mode, QIcon::State state);
+        virtual QIconEngine* clone() const;
 
     private:
         const QColor m_color;
@@ -118,22 +120,24 @@ QPixmap LedIconEngine::pixmap(const QSize &size, QIcon::Mode mode, QIcon::State
     return pix;
 }
 
+QIconEngine* LedIconEngine::clone() const
+{
+    LedIconEngine* newEngine = new LedIconEngine(m_color, m_state);
+
+    return newEngine;
+}
+
 
 Images::Images()
 {
     initializeLeds();
     initializeNickIcons();
-    initializeKimifaceIcons();
 }
 
 Images::~Images()
 {
 }
 
-QIcon Images::getKimproxyAway() const { return kimproxyAway; }
-QIcon Images::getKimproxyOnline() const { return kimproxyOnline; }
-QIcon Images::getKimproxyOffline() const { return kimproxyOffline; }
-
 QPixmap Images::getNickIcon(NickPrivilege privilege,bool isAway) const
 {
     return nickIcons[privilege][isAway?1:0];
@@ -172,24 +176,40 @@ void Images::initializeLeds()
     m_highlightsLedOn = getLed(m_highlightsColor,true);
 }
 
-void Images::initializeKimifaceIcons()
-{
-    kimproxyAway = KIcon("kimproxyaway");
-    kimproxyOnline = KIcon("kimproxyonline");
-    kimproxyOffline = KIcon("kimproxyoffline");
-}
-
 // NickIcons
 
 void Images::initializeNickIcons()
 {
 
     QString iconTheme = Preferences::self()->iconTheme();
-    QStringList icons = KGlobal::dirs()->findAllResources("data","konversation/themes/"+iconTheme+"/*.png");
+    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konversation/themes/"+iconTheme, QStandardPaths::LocateDirectory);
+    QStringList icons;
+
+    foreach(const QString& dir, dirs)
+    {
+        QDir themedir(dir);
+
+        foreach(const QString& file, themedir.entryList(QStringList() << "*.png", QDir::Files))
+        {
+            icons.append(dir + QLatin1Char('/') + file);
+        }
+    }
 
     if( icons.count() < 7 ) // Sanity
-        icons = KGlobal::dirs()->findAllResources("data","konversation/themes/default/*.png");
-    if ( icons.count() < 7 ) // Sanity
+    {
+        dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "konversation/themes/default/*.png");
+
+        foreach(const QString& dir, dirs)
+        {
+            QDir themedir(dir);
+
+            foreach(const QString& file, themedir.entryList(QStringList() << "*.png", QDir::Files))
+            {
+                icons.append(dir + QLatin1Char('/') + file);
+            }
+        }
+    }
+    if ( icons.count() < 7 || icons.count() > 8) // Sanity
         return;
     icons.sort();
     QStringList::ConstIterator it = icons.constBegin();
@@ -202,6 +222,11 @@ void Images::initializeNickIcons()
     QPixmap elementAway(*it);
     nickIconAwayPath = *it;
     ++it;
+    QPixmap elementAwayStacked;
+    if (icons.count() == 8 && iconTheme == QLatin1String("default")) {
+        elementAwayStacked = (*it);
+        ++it;
+    }
     QPixmap elementHalfOp(*it);
     nickIconPaths[HalfOp] = *it;
     ++it;
@@ -221,31 +246,36 @@ void Images::initializeNickIcons()
     nickIcons[Normal][1] = overlayPixmaps( nickIcons[Normal][0], elementAway );
 
     nickIcons[Voice][0] = overlayPixmaps( elementNormal, elementVoice );
-    nickIcons[Voice][1] = overlayPixmaps( nickIcons[Voice][0], elementAway );
+    nickIcons[Voice][1] = overlayPixmaps( nickIcons[Voice][0], elementAwayStacked.isNull() ? elementAway : elementAwayStacked );
 
     nickIcons[HalfOp][0] = overlayPixmaps( elementNormal, elementHalfOp );
-    nickIcons[HalfOp][1] = overlayPixmaps( nickIcons[HalfOp][0], elementAway );
+    nickIcons[HalfOp][1] = overlayPixmaps( nickIcons[HalfOp][0], elementAwayStacked.isNull() ? elementAway : elementAwayStacked );
 
     nickIcons[Op][0] = overlayPixmaps( elementNormal, elementOp );
-    nickIcons[Op][1] = overlayPixmaps( nickIcons[Op][0], elementAway );
+    nickIcons[Op][1] = overlayPixmaps( nickIcons[Op][0], elementAwayStacked.isNull() ? elementAway : elementAwayStacked );
+
+    if (iconTheme == QLatin1String("default")) {
+        nickIcons[Owner][0] = elementOwner;
+    } else {
+        nickIcons[Owner][0] = overlayPixmaps( elementNormal, elementOwner );
+    }
 
-    nickIcons[Owner][0] = overlayPixmaps( elementNormal, elementOwner );
     nickIcons[Owner][1] = overlayPixmaps( nickIcons[Owner][0], elementAway );
 
-    nickIcons[Admin][0] = overlayPixmaps( elementNormal, elementAdmin );
-    nickIcons[Admin][1] = overlayPixmaps( nickIcons[Admin][0], elementAway );
+    if (iconTheme == QLatin1String("default")) {
+        nickIcons[Admin][0] = elementAdmin;
+    } else {
+        nickIcons[Admin][0] = overlayPixmaps( elementNormal, elementAdmin );
+    }
 
-    /*
-    // why doesn't it work?
-    nickIcons[Op][0] = elementNormal;
-    bitBlt( &nickIcons[Op][0], 0, 0, &elementOp, 0, 0, -1, -1, Qt::CopyROP );
-    nickIcons[Op][1] = nickIcons[Op][0];
-    bitBlt( &nickIcons[Op][1], 0, 0, &elementAway, 0, 0, -1, -1, Qt::CopyROP );
-    */
+    nickIcons[Admin][1] = overlayPixmaps( nickIcons[Admin][0], elementAway );
 }
 
 QIcon Images::getLed(const QColor& col,bool state)
 {
+    Q_UNUSED(col)
+    Q_UNUSED(state)
+
     return QIcon(new LedIconEngine(col, state));
 }
 
@@ -335,4 +365,4 @@ QIcon Images::getHighlightsLed()
         return m_highlightsLedOn;
 }
 
-#include "images.moc"
+
